def get_slab(m=1):
    """
    Create a slab configuration. 'm' is the number of repetitions
    of the 2-atom (100) unit cell, so only integer number of slab
    layers are possible.
    """
    # BULK
    # Set up lattice
    vector_a = [2.93319206545, 0.0, 0.0]*Angstrom
    vector_b = [0.0, 2.93319206545, 0.0]*Angstrom
    vector_c = [0.0, 0.0, 4.14816]*Angstrom
    lattice = UnitCell(vector_a, vector_b, vector_c)

    # Define elements
    elements = [Silver, Silver]

    # Define coordinates
    fractional_coordinates = [[ 0.5,  0.5,  0.25],
                              [ 0. ,  0. ,  0.75 ]]

    # Set up configuration
    bulk_configuration = BulkConfiguration(
        bravais_lattice=lattice,
        elements=elements,
        fractional_coordinates=fractional_coordinates
        )

    # SLAB
    slab = bulk_configuration.repeat(1,1,m)
    vecs = slab.primitiveVectors()
    vecs[2,2] += 15*Angstrom
    slab.setPrimitiveVectors(vecs[0], vecs[1], vecs[2])
    coords = slab.cartesianCoordinates()
    coords[:,2] += 5.0*Angstrom
    slab.setCartesianCoordinates(coords)

    # 1 ghost atom
    slab._AtomicConfiguration__ghost_atoms = [len(slab)-2, len(slab)-1]
    return slab

for m in [2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20]:
    nc = 'Ag100_slab_%i.nc' % m

    # -------------------------------------------------------------
    # Surface Configuration
    # -------------------------------------------------------------
    slab_configuration = get_slab(m)

    # -------------------------------------------------------------
    # Calculator
    # -------------------------------------------------------------
    #----------------------------------------
    # Basis Set
    #----------------------------------------
    basis_set = [
        LDABasis.Silver_SingleZetaPolarized,
        ]

    #----------------------------------------
    # Numerical Accuracy Settings
    #----------------------------------------
    k_point_sampling = MonkhorstPackGrid(
        na=9,
        nb=9,
        nc=1,
        )
    numerical_accuracy_parameters = NumericalAccuracyParameters(
        k_point_sampling=k_point_sampling,
        )

    #----------------------------------------
    # Poisson Solver Settings
    #----------------------------------------
    poisson_solver = FastFourier2DSolver(
        boundary_conditions=[[PeriodicBoundaryCondition(),PeriodicBoundaryCondition()],
                             [PeriodicBoundaryCondition(),PeriodicBoundaryCondition()],
                             [NeumannBoundaryCondition(),DirichletBoundaryCondition()]]
        )

    #----------------------------------------
    # Calculator
    #----------------------------------------
    calculator = LCAOCalculator(
        basis_set=basis_set,
        numerical_accuracy_parameters=numerical_accuracy_parameters,
        poisson_solver=poisson_solver,
        )
    slab_configuration.setCalculator(calculator)
    nlprint(slab_configuration)
    slab_configuration.update()
    nlsave(nc, slab_configuration)

    # -------------------------------------------------------------
    # Chemical Potential
    # -------------------------------------------------------------
    chemical_potential = ChemicalPotential(slab_configuration)
    nlsave(nc, chemical_potential)
    nlprint(chemical_potential)

    # -------------------------------------------------------------
    # Electrostatic Difference Potential
    # -------------------------------------------------------------
    electrostatic_difference_potential = ElectrostaticDifferencePotential(slab_configuration)
    nlsave(nc, electrostatic_difference_potential)
